==> librenms-1.26v0.tgz: librenms/html/includes/graphs/device/canopy_generic_signalHV.inc.php <==
<?php
/*
 * LibreNMS
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.  Please see LICENSE.txt at the top level of
 * the source code distribution for details.
 */

require 'includes/graphs/common.inc.php';
$rrdfilename = rrd_name($device['hostname'], 'canopy-generic-signalHV');
if (file_exists($rrdfilename)) {
    $rrd_options .= " COMMENT:'dBm                Now       Ave      Max     \\n'";
    $rrd_options .= ' DEF:vertical='.$rrdfilename.':vertical:AVERAGE ';
    $rrd_options .= ' DEF:horizontal='.$rrdfilename.':horizontal:AVERAGE ';
    $rrd_options .= ' DEF:combined='.$rrdfilename.':combined:AVERAGE ';
    $rrd_options .= " LINE2:vertical#FF0000:'Vertical       ' ";
    $rrd_options .= ' GPRINT:vertical:LAST:%0.2lf%s ';
    $rrd_options .= ' GPRINT:vertical:MIN:%0.2lf%s ';
    $rrd_options .= ' GPRINT:vertical:MAX:%0.2lf%s\\\l ';
    $rrd_options .= " LINE2:horizontal#003EFF:'Horizontal      ' ";
    $rrd_options .= ' GPRINT:horizontal:LAST:%0.2lf%s ';
    $rrd_options .= ' GPRINT:horizontal:MIN:%0.2lf%s ';
    $rrd_options .= ' GPRINT:horizontal:MAX:%0.2lf%s\\\l ';
    $rrd_options .= " LINE2:combined#FFA500:'Combined      ' ";
    $rrd_options .= ' GPRINT:combined:LAST:%0.2lf%s ';
    $rrd_options .= ' GPRINT:combined:MIN:%0.2lf%s ';
    $rrd_options .= ' GPRINT:combined:MAX:%0.2lf%s\\\l ';
}

==> librenms-1.50v0.tgz: librenms/html/includes/graphs/device/canopy_generic_signalHV.inc.php <==
<?php
/*
 * LibreNMS
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.  Please see LICENSE.txt at the top level of
 * the source code distribution for details.
 */

require 'includes/graphs/common.inc.php';
$rrdfilename = rrd_name($device['hostname'], 'canopy-generic-signalHV');
if (rrdtool_check_rrd_exists($rrdfilename)) {
    $rrd_options .= " COMMENT:'dBm                Now       Ave      Max     \\n'";
    $rrd_options .= ' DEF:vertical='.$rrdfilename.':vertical:AVERAGE ';
    $rrd_options .= ' DEF:horizontal='.$rrdfilename.':horizontal:AVERAGE ';
    $rrd_options .= ' DEF:combined='.$rrdfilename.':combined:AVERAGE ';
    $rrd_options .= " LINE2:vertical#FF0000:'Vertical       ' ";
    $rrd_options .= ' GPRINT:vertical:LAST:%0.2lf%s ';
    $rrd_options .= ' GPRINT:vertical:MIN:%0.2lf%s ';
    $rrd_options .= ' GPRINT:vertical:MAX:%0.2lf%s\\\l ';
    $rrd_options .= " LINE2:horizontal#003EFF:'Horizontal      ' ";
    $rrd_options .= ' GPRINT:horizontal:LAST:%0.2lf%s ';
    $rrd_options .= ' GPRINT:horizontal:MIN:%0.2lf%s ';
    $rrd_options .= ' GPRINT:horizontal:MAX:%0.2lf%s\\\l ';
    $rrd_options .= " LINE2:combined#FFA500:'Combined      ' ";
    $rrd_options .= ' GPRINT:combined:LAST:%0.2lf%s ';
    $rrd_options .= ' GPRINT:combined:MIN:%0.2lf%s ';
    $rrd_options .= ' GPRINT:combined:MAX:%0.2lf%s\\\l ';
}
